# `fsspeckit` API Reference

Welcome to the `fsspeckit` API reference documentation. This section provides detailed information on the various modules, classes, and functions available in the library.

> **Package Structure**: fsspeckit is organized into domain packages. See [Architecture](../architecture.md) for details.

## Core Modules

*   [`fsspeckit.core.base`](fsspeckit.core.base.md)

*   [`fsspeckit.core.ext`](fsspeckit.core.ext.md)

## Storage Options

*   [`fsspeckit.storage_options.base`](fsspeckit.storage_options.base.md)

*   [`fsspeckit.storage_options.cloud`](fsspeckit.storage_options.cloud.md)

*   [`fsspeckit.storage_options.core`](fsspeckit.storage_options.core.md)

*   [`fsspeckit.storage_options.git`](fsspeckit.storage_options.git.md)

## Utils (Backwards Compatibility)

*   [`fsspeckit.utils.datetime`](fsspeckit.utils.datetime.md) - Date and time utilities

*   [`fsspeckit.utils.logging`](fsspeckit.utils.logging.md) - Logging configuration and utilities

*   [`fsspeckit.utils.misc`](fsspeckit.utils.misc.md) - Miscellaneous utility functions

*   [`fsspeckit.utils.polars`](fsspeckit.utils.polars.md) - Polars DataFrame utilities

*   [`fsspeckit.utils.pyarrow`](fsspeckit.utils.pyarrow.md) - PyArrow utilities and integrations

*   [`fsspeckit.utils.sql`](fsspeckit.utils.sql.md) - SQL query and filter utilities

*   [`fsspeckit.utils.types`](fsspeckit.utils.types.md) - Type definitions and utilities

> **Note**: API documentation for the new domain packages (datasets, sql, common) will be added in a future update. The utils modules above provide backwards compatibility for all functionality.